#include "cpcrslib.h"
#include "cpcwyzlib.h"
#include "sprites.h"
#include "graphics.h"
#include "tiles.h"
#include "music_data.h"
#include "music.h"
#include "utils.h"
#include "randomfloor.h"
#include "player.h"
#include "enemy.h"
#include "pathfinding.h"

#define MAP_WIDTH 60
#define MAP_HEIGHT 60
#define MAP_SIZE MAP_WIDTH*MAP_HEIGHT/8
#define MAX_ENEMIES 15
#define MAX_POTIONS 3
#define MAX_HEALTH 50
#define HEAL_FACTOR 10

char mMap[MAP_SIZE];
char auxMap[MAP_SIZE];

unsigned int xNextMap;
unsigned int yNextMap;
char estadoNextMap;
char newEstadoNextMap;
unsigned int TILES_TO_PROCESS;

typedef struct mLadder
{
    unsigned char x;
    unsigned char y;
    char *sprite;
} TLadder;

typedef struct mObject
{
    unsigned char x;
    unsigned char y;
    unsigned char picked;
    char *sprite;
} TObject;

extern char mHuman[];
extern char mSkeleton[];
extern char mTiramocoSprites[];
extern char mMurcielagoSprites[];

extern char mVestSprite[];

extern char mTileSprites[];

//extern char mCharacterDataBar[];
extern char mCharacterDataBar0[];
extern char mCharacterDataBar1[];
extern char mCharacterDataBar2[];
extern char mCharacterDataBar3[];

extern char mLadderSprite[];
extern char mTileTransition[];
extern char mMocoSprite[];
extern char mPotionSprite[];
extern char mCavebolaTitle[];
extern char mHumanSkeletonTitle[];

extern char mHealthBarSprite[];
extern char mHealthBarEmptySprite[];

unsigned char mLevel;
unsigned char waitingTurns;

//unsigned char cad_aux[4];

TTile mTiles[MAX_TILES];
TEnemy mEnemies[MAX_ENEMIES];
TPlayer player;
TLadder mLadder;
TObject mPotions[MAX_POTIONS];
TObject mArmor;

void CreateTiles()
{
    TTile* t = &mTiles[0];
    t->sprite = mTileSprites + 32;
    t->walkable = 1;

    t = &mTiles[1];
    t->sprite = mTileSprites + 64;
    t->walkable = 0;

    t = &mTiles[2];
    t->sprite = mTileSprites;
    t->walkable = 0;

    t = &mTiles[3];
    t->sprite = mTileTransition;
    t->walkable = 0;
}
void CreatePlayer()
{
    player.x = 0;
    player.y = 0;
    player.sprite = mHuman;
    player.spriteDeath = mHuman + 256;
    player.direction = 0;
    player.moved = 0;
    player.armor = 10;
    player.strengthMax = 3;
    player.strengthMin = 1;

    // Only restore player health if new game
    if (mLevel == 1)
        player.health = 20;

    player.critProb = 5;
    player.potions = 0;

    player.alive = 1;
}

void CreateMoco(TEnemy *pEnemy)
{
    pEnemy->moco.range = 5;
    pEnemy->moco.speedX = 0;
    pEnemy->moco.speedY = 0;
    pEnemy->moco.x = pEnemy->x;
    pEnemy->moco.y = pEnemy->y; 
    pEnemy->moco.damage = 10;
    pEnemy->moco.sprite = mMocoSprite;
}

void CreateEnemies()
{
    unsigned int auxPos;
    unsigned int tiramocoPos;
    unsigned int i;

    TEnemy* e;

    for(i = 0; i <= 2; ++i)
    {
        e = &mEnemies[i];
        if(i == 0) auxPos = RandomPosition(mMap, MAP_HEIGHT, MAP_WIDTH);
        else if(i == 1) auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mEnemies[i-1].x, mEnemies[i-1].y, 20, 50);
        else auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mEnemies[i-1].x, mEnemies[i-2].y, 20, 50);
        tiramocoPos = auxPos;
        e->x = auxPos % MAP_WIDTH; //10;
        e->y = auxPos / MAP_WIDTH; //18;
        e->sprite = mTiramocoSprites;
        e->spriteDeath = mTiramocoSprites + 256;
        e->direction = 0;
        e->currentAction = AI_STAND_GROUND;
        e->currentStrategy = ST_PATROL;
        e->hearThreshold = 0;
        e->hearRadius = 5;
        e->sightRadius = 9;
        e->pathNodes = 0;
        e->currentPathNode = 0;
        e->pathDir = 0;
        e->armor = 20;
        e->health = 8;
        e->strengthMin = 2;
        e->strengthMax = 10;
        e->critProb = 1;
        e->alive = 1;
        e->type = TIRAMOCO;
        e->turn = 0;
        e->redraw = 1;
        e->blocked = 0;

        if(e->type = TIRAMOCO)
        {
            CreateMoco(e);
        }
    }

    for(i = 3; i <= 5; ++i)
    {
        auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mPotions[i-3].x, mPotions[i-3].y, 1, 3);
        e = &mEnemies[i];
        e->x = auxPos % MAP_WIDTH;//30;
        e->y = auxPos / MAP_WIDTH;//30;
        e->sprite = mSkeleton;
        e->spriteDeath = mSkeleton + 256;
        e->direction = 0;
        e->currentAction = AI_STAND_GROUND;
        e->currentStrategy = ST_PATROL;
        e->hearThreshold = 0;
        e->hearRadius = 5;
        e->sightRadius = 10;

        auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mEnemies[i].x, mEnemies[i].y, 10, 20);
        
        PathFinding(e->x, e->y, auxPos % MAP_WIDTH, auxPos / MAP_WIDTH, e, mMap);
        //e->pathNodes = 10;
        /*e->pathNodes = 8;
        e->path[0] = 30;
        e->path[1] = 30;
        e->path[2] = 30;
        e->path[3] = 31;
        e->path[4] = 31;
        e->path[5] = 31;
        e->path[6] = 31;
        e->path[7] = 30;*/
        e->currentPathNode = 2;
        e->pathDir = 2;
        e->armor = 40;
        e->health = 6;
        e->strengthMin = 2;
        e->strengthMax = 5;
        e->critProb = 1;
        e->alive = 1;
        e->type = ESQUELETO;
        e->turn = 0;
        e->redraw = 1;
        e->blocked = 0;
    }

    for(i = 6; i < MAX_ENEMIES; ++i)
    {
        //auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mEnemies[i-1].x, mEnemies[i-2].y, 20, 50);
        auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, 20*((i-6)%3)+10, 20*((i-6)/3)+10, 0, 8);
        e = &mEnemies[i];
        e->x = auxPos % MAP_WIDTH;//12;
        e->y = auxPos / MAP_WIDTH;//12;
        e->sprite = mMurcielagoSprites;
        e->spriteDeath = mMurcielagoSprites + 256;
        e->direction = 0;
        e->currentAction = AI_STAND_GROUND;
        e->currentStrategy = ST_PATROL;
        e->hearThreshold = 0;
        e->hearRadius = 7;
        e->sightRadius = 0;
        e->pathNodes = 0;
        e->currentPathNode = 0;
        e->pathDir = 0;
        e->armor = 10;
        e->health = 5;
        e->strengthMin = 1;
        e->strengthMax = 5;
        e->critProb = 0;
        e->alive = 1;
        e->type = MURCIELAGO;
        e->turn = 0;
        e->redraw = 1;
        e->blocked = 0;
    }
}

void UpdateEnemies()
{
    int i;
    TEnemy *e;

    for(i = 0; i < MAX_ENEMIES; i++)
    {
        e = &mEnemies[i];

        if(e->type != MURCIELAGO)
            e->armor += 5;

        if(mLevel % 2 == 0)
        {
            switch(e->type)
            {   
                case ESQUELETO:
                    e->health +=1;

                    if(e->health % 2 == 0)
                    {
                        e->strengthMin += 1;
                        e->strengthMax += 1;
                    }
                    break;
                case MURCIELAGO:
                    e->strengthMin += 1;
                    e->strengthMax += 1;
                    break;
                case TIRAMOCO:
                    e->strengthMax += 2;
                    break;
            }  
        }        
    }
}

void GreyBackground()
{
    unsigned char i = 0;
    unsigned char j = 0;
    int pDir = 0xC000;

    for (i = 0; i < 20; ++i)
    {
        for (j = 0; j < 25; ++j)
        {
            PutSprite4x8(mTileSprites, pDir);

            pDir += 4;
        }
    }
}

void GenerateNextMap()
{
    //Code to generate slowly the next map
    if(estadoNextMap == 3)
    {
        Pause(28);
    }
    else
    {
        newEstadoNextMap = GenerateCavePart(auxMap, MAP_HEIGHT, MAP_WIDTH, estadoNextMap, xNextMap, yNextMap, TILES_TO_PROCESS);
        if(estadoNextMap == 0) Pause(8);
        else if(estadoNextMap == 2) Pause(3);
        xNextMap = xNextMap + TILES_TO_PROCESS;
        if(newEstadoNextMap != estadoNextMap)
        {
            xNextMap = 1;
            yNextMap = 1;
            estadoNextMap = newEstadoNextMap;
            if(newEstadoNextMap == 1) 
            {
                TILES_TO_PROCESS = 15;
            }
            else if(newEstadoNextMap == 2)
            {
                TILES_TO_PROCESS = 30;
            }
        }
        else if(xNextMap >= MAP_WIDTH-1)
        {
            xNextMap = 1;
            ++yNextMap;
        }
    }
}

void ShowMenu()
{

    PlaySong(SOUND_TABLE_MAINEXPL, RULE_TABLE_MAINEXPL, EFFECT_TABLE, SONG_TABLE_MENU);

    GreyBackground();
    //cpc_PutSp(mCavebolaTitle, 36, 48, 0xC0A0 + 0x0010);
    //cpc_PutSp(mHumanSkeletonTitle, 58, 18, 0xC550 + 0x0033); 

    do
    {
        GenerateNextMap();

        cpc_PrintGphStrXY("1<;PLAY", 22, 85);
        cpc_PrintGphStrXY("2<;CONTROLS", 22, 100);
        //cpc_PrintGphStrXY("3<;INSTRUCTIONS", 22, 115);

        if(cpc_TestKey(9))
        {
            PlayEffect(MENU_MOV_FX);
            GreyBackground();
            //cpc_PutSp(mCavebolaTitle, 36, 48, 0xC0A0 + 0x0010);
            cpc_PrintGphStrXY("ARROW;UP;-;MOVE;UP", 18, 80);
            cpc_PrintGphStrXY("ARROW;LEFT;-;MOVE;LEFT", 18, 90);
            cpc_PrintGphStrXY("ARROW;RIGHT;-;MOVE;RIGHT", 18, 100);
            cpc_PrintGphStrXY("ARROW;DOWN;-;MOVE;DOWN", 18, 110);
            cpc_PrintGphStrXY("1;<PLAY", 18, 150);
            cpc_PrintGphStrXY("2;<MENU", 50, 150);

            while(!cpc_TestKey(9) && !cpc_TestKey(8)){}
            PlayEffect(MENU_MOV_FX);

            if(cpc_TestKey(8))break;
            GreyBackground();
            //cpc_PutSp(mCavebolaTitle, 36, 48, 0xC0A0 + 0x0010);
            //cpc_PutSp(mHumanSkeletonTitle, 58, 18, 0xC550 + 0x0033); 
        }
        /*else if(cpc_TestKey(10))
        {
            PlayEffect(MENU_MOV_FX);
            GreyBackground();
            //cpc_PutSp(mCavebolaTitle, 36, 48, 0xC0A0 + 0x0010);
            cpc_PrintGphStrXY("INSTRUCTIONS", 30, 40);
            cpc_PrintGphStrXY("GET;THE;ANTIDOTES;IN;ORDER;TO", 10, 80);
            cpc_PrintGphStrXY("ESCAPE;FROM;THE;CAVE<", 10, 90);
            cpc_PrintGphStrXY("BE;CAREFUL<;YOU;MIGHT;ENCOUNTER", 10, 100);
            cpc_PrintGphStrXY("DANGEROUS;ENEMIES<", 10, 110);
            cpc_PrintGphStrXY("GO<;RUN<;ROGUELIO<", 10, 120);
            cpc_PrintGphStrXY("1;<PLAY", 18, 150);
            cpc_PrintGphStrXY("2;<MENU", 50, 150);

            while(!cpc_TestKey(9) && !cpc_TestKey(8)){}
            PlayEffect(MENU_MOV_FX);

            if(cpc_TestKey(8))break;
            GreyBackground();
        }*/

    } 
    while(!cpc_TestKey(8)); 

    PlayEffect(MENU_MOV_FX);
}
void ShowLoading()
{
    char i;
    GreyBackground();
    for (i = 0; i < 25; ++i)
        cpc_PutMaskSp(mLadderSprite, 8, 4, 0xC000 + i * 0x0050 + 0x0024);
    cpc_PrintGphStrXY("LOADING", 30, 100); 

    cpc_PutMaskSp(mHuman + 192, 8, 4, 0xC5A0 + 0x0024);

}
void ShowDeath()
{
    GreyBackground();
    cpc_PrintGphStrXY("WASTED", 30, 100);

     cpc_PutMaskSp(mHuman + 256, 8, 4, 0xC5A0 + 0x0024);
     cpc_PutMaskSp(mSkeleton, 8, 4, 0xC5A0 + 0x0020);
     cpc_PutMaskSp(mSkeleton + 128, 8, 4, 0xC5A0 + 0x0032);
}

void Combat(TPlayer *pPlayer, TEnemy *pEnemy)
{
    float damage = StrikeEnemy(pPlayer);

    //Damage reduction of the armor
    damage =  damage * DamageReduction(pEnemy->armor);

    if (pEnemy->health <= damage)
    {
        pEnemy->alive = 0;
        pEnemy->redraw = 1;
        MarkTile(pEnemy->x, pEnemy->y);
        PlayEffect(ENE_DEATH_FX);
    }
    else
    {
        if(pEnemy->type == TIRAMOCO)
        {
            if(pEnemy->x > pPlayer->x)
            {
                pEnemy->direction = 128;
            }
            else if(pEnemy->x < pPlayer->x)
            {
                pEnemy->direction = 0;
            }
            else if(pEnemy->y > pPlayer->y)
            {
                pEnemy->direction = 192;
            }
            else if(pEnemy->y < pPlayer->y)
            {
                pEnemy->direction = 64;
            }
        }

        SetColors(mPaletteStrikeHW);
        pEnemy->health -= damage;
        Pause(20);
        SetColors(mPaletteHW);
    }
}

char IsEnemyInFront(unsigned char direction, unsigned char *pEnemy)
{   
    volatile char inFront = 0;
    TEnemy *enemy;

    char dx;
    char dy;

    unsigned char i;
    for(i = 0; i < MAX_ENEMIES && inFront == 0; ++i)
    {
        enemy = &mEnemies[i];
        *pEnemy = i;

        if (enemy->alive == 1)
        {
            dx = player.x - enemy->x;
            dy = player.y - enemy->y;

            switch(direction)
            {
                case 0:
                    if(dx == -1 && dy == 0)
                        inFront = 1;
                    break;
                case 1:
                    if(dx == 1 && dy == 0)
                        inFront = 1;
                    break;
                case 2:
                    if(dy == 1 && dx == 0)
                        inFront = 1;
                    break;
                case 3:
                    if(dy == -1 && dx == 0)
                        inFront = 1;
                    break;
                default:
                    break;
            }
        }
    }

    return inFront;
}

void UpdateMoco(TEnemy *pEnemy, TPlayer *pPlayer)
{
    if(pEnemy->moco.range != 0 && (pEnemy->moco.speedX != 0 || pEnemy->moco.speedY != 0))
    {
        if (CheckSameRoom(pPlayer->x, pPlayer->y, pEnemy->moco.x, pEnemy->moco.y) == 1 && 
            (pEnemy->moco.x != pEnemy->x || pEnemy->moco.y != pEnemy->y))
            MarkTile(pEnemy->moco.x, pEnemy->moco.y);

        pEnemy->moco.x = pEnemy->moco.x + pEnemy->moco.speedX;
        pEnemy->moco.y = pEnemy->moco.y + pEnemy->moco.speedY;

        --pEnemy->moco.range;

        //IMPACTO
        if(pEnemy->moco.x == pPlayer->x && pEnemy->moco.y == pPlayer->y)
        {
            if (pPlayer->health <= pEnemy->moco.damage)
            {
                //GAME OVER
                pPlayer->health = 0;
                pPlayer->alive = 0;
            }
            else
                pPlayer->health -= pEnemy->moco.damage;

            pEnemy->moco.range = 0;
            SetColors(mPaletteHitHW);
            PlayEffect(ATTACK_FX);
            Pause(20);
            SetColors(mPaletteHW);
        }


    }
    else if (pEnemy->moco.range == 0)
    {
        if (CheckSameRoom(pPlayer->x, pPlayer->y, pEnemy->moco.x, pEnemy->moco.y) == 1)
            MarkTile(pEnemy->moco.x, pEnemy->moco.y);
        pEnemy->moco.range = 5;
        pEnemy->moco.speedX = 0;
        pEnemy->moco.speedY = 0;
        pEnemy->moco.x = pEnemy->x;
        pEnemy->moco.y = pEnemy->y;
    }
}

char isPotionUnderPlayer(unsigned char *pPotion){
    volatile char isUnder = 0;
    TObject *potion;

    unsigned char i;
    for(i = 0; i < MAX_POTIONS && isUnder == 0; ++i)
    {
        potion = &mPotions[i];
        *pPotion = i;

        if(potion->picked == 0 && player.x == potion->x && player.y == potion->y)
            isUnder = 1;
    }

    return isUnder;
}

void PlayerAction()
{
    unsigned char i = 0;
    unsigned char k = 0;
    unsigned char moved = 0;
    char x[] = {1, -1, 0, 0};
    char y[] = {0, 0, -1, 1};
    char d[] = {0, 128, 192, 64};

    TEnemy *enemy;
    TObject *potion;


    if(isPotionUnderPlayer(&i))
    {
        potion = &mPotions[i];
        potion->picked = 1;
        ++player.potions;

        SetColors(mPalettePotionHW);
        PlayEffect(MENU_MOV_FX);
        Pause(40);
        SetColors(mPaletteHW);

        i = 0;

        while(i < HEAL_FACTOR && player.health < MAX_HEALTH)
        {
            ++player.health;
            ++i;
        }

    }

    
    if(player.x == mArmor.x && player.y == mArmor.y && mArmor.picked == 0)
    {
        mArmor.picked = 1;
        MarkTile(mArmor.x, mArmor.y);

        if(player.armor <= 90)
            player.armor += 10;

        PlayEffect(MENU_MOV_FX);
    }
    

    for (k = 0; k < 4 && !moved; ++k)
    {
        if (cpc_TestKey(k) && CheckWalkableTile(mMap, mTiles, MAP_WIDTH, player.x + x[k], player.y + y[k]))
        {
            moved = 1;

            if (!IsEnemyInFront(k, &i))
            {
                if ((k == 0 && player.x % 20 == 19) || (k == 1 && player.x % 20 == 0) ||
                    (k == 2 && player.y % 20 == 0) || (k == 3 && player.y % 20 == 19))
                {
                    MarkAllTiles();

                    for (i = 0; i < MAX_ENEMIES; ++i)
                    {
                        enemy = &mEnemies[i];
                        if (CheckSameRoom(player.x + x[k], player.y + y[k], enemy->x, enemy->y) == 1)
                            enemy->redraw = 1;
                    }
                }
                else
                    MarkTile(player.x, player.y);

                player.x += x[k];
                player.y += y[k];
                player.direction = d[k];
            }
            else
            {
                enemy = &mEnemies[i];
                MarkTile(player.x, player.y);
                player.direction = d[k];
                Combat(&player, enemy);
            }
        }
        else if (cpc_TestKey(k) && !CheckWalkableTile(mMap, mTiles, MAP_WIDTH, player.x + x[k], player.y + y[k]))
        {
            moved = 1;
            
            MarkTile(player.x, player.y);
            player.direction = d[k];
            PlayEffect(COLLISION_FX);
        }
    }
}

void DrawPotion(TObject *pPotion)
{
    cpc_PutMaskSp(pPotion->sprite, 8, 4, 0xC000 + 0x0050*(pPotion->y%20) + (pPotion->x%20)*0x0004);
}

void DrawStatusBar()
{
    unsigned char h = 0;

    cpc_PrintGphStrXY("ARMOR", 32, 169);
    PrintNumber(player.armor, 34, 185);
    cpc_PrintGphStrXY("LEVEL", 44, 169);
    PrintNumber(mLevel, 46, 185);

    cpc_PrintGphStrXY("ROGUELIO", 6, 169);
    // Draw the life bar   
    for (h = 0; h < MAX_HEALTH; h += 2)
    {
        if (h < player.health)
            cpc_PutSp(mHealthBarSprite, 8, 1, 0xC734 + h/2);
        else
            cpc_PutSp(mHealthBarEmptySprite, 8, 1, 0xC734 + h/2);
    }

    cpc_PrintGphStrXY("FRAGMENTS", 58, 169);
    switch(player.potions)
    {
        case 3:
            cpc_PutMaskSp(mPotionSprite, 8, 4, 0xC730 + 0x0046);
        case 2:
            cpc_PutMaskSp(mPotionSprite, 8, 4, 0xC730 + 0x0043);
        case 1:
            cpc_PutMaskSp(mPotionSprite, 8, 4, 0xC730 + 0x0040);
        case 0:
            break;
    }

}

void InitializeLevel()
{
    TObject *potion;
    char e;
    unsigned int auxPos;

    PlaySong(SOUND_TABLE_MAINEXPL, RULE_TABLE_MAINEXPL, EFFECT_TABLE, SONG_TABLE_LOADMAP);

    GenerateCavePart(auxMap, MAP_HEIGHT, MAP_WIDTH, estadoNextMap, xNextMap, yNextMap, 0);
    memcpy(mMap, auxMap, MAP_SIZE);
    EnsureConnectivity(mMap, auxMap, MAP_HEIGHT, MAP_WIDTH);

    estadoNextMap = 0;
    xNextMap = 1;
    yNextMap = 1;
    TILES_TO_PROCESS = 60;

    CreatePlayer();
    

    auxPos = RandomPosition(mMap, MAP_HEIGHT, MAP_WIDTH);
    mLadder.x = auxPos % MAP_WIDTH;
    mLadder.y = auxPos / MAP_WIDTH;
    mLadder.sprite =  mLadderSprite;

    for(e = 0; e < MAX_POTIONS; ++e)
    {       
        potion = &mPotions[e];
        if(e == 0) auxPos = RandomPosition(mMap, MAP_HEIGHT, MAP_WIDTH);
        else if(e == 1) auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mPotions[e-1].x, mPotions[e-1].y, 20, 50);
        else auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mPotions[e-1].x, mPotions[e-2].y, 20, 50);
        potion->x = auxPos % MAP_WIDTH;
        potion->y = auxPos / MAP_WIDTH;
        potion->picked = 0;
        potion->sprite =  mPotionSprite;
    }

    CreateEnemies();

    
    mArmor.sprite = mVestSprite;
    if(mLevel == 1 || mLevel % 3 == 0)
    {
        auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, player.x, player.y, 30, 50);
        mArmor.x = auxPos % MAP_WIDTH;
        mArmor.y = auxPos / MAP_WIDTH;
        mArmor.picked = 0;
    }
    else
    {
        mArmor.x = 0;
        mArmor.y = 0;
        mArmor.picked = 1;
    }
    
    //Ejemplo de uso de RandomPositionBound: El jugador saldría a una distancia de 
        //entre 2 y 7 casillas (en cada coordenada) de la escalera.
        //auxPos = RandomPositionBound(mMap, MAP_HEIGHT, MAP_WIDTH, mLadder.x, mLadder.y, 2, 7);
    auxPos = RandomPosition(mMap, MAP_HEIGHT, MAP_WIDTH);
    player.x = auxPos % MAP_WIDTH;
    player.y = auxPos / MAP_WIDTH;

    SetTileMap(mMap, MAP_HEIGHT, MAP_WIDTH);
    SetTileSet(mTiles);

    GreyBackground();

    DrawMap(player.x, player.y, 0xC000);

    /*DrawPlayer(&player);

    if(CheckSameRoom(player.x, player.y, mLadder.x, mLadder.y) == 1)
        DrawLadder(&mLadder);   

    for (e = 0; e < MAX_POTIONS; ++e)
    {
        potion = &mPotions[e];
        if (CheckSameRoom(player.x, player.y, potion->x, potion->y) == 1)
            DrawPotion(potion);
    }

    for (e = 0; e < MAX_ENEMIES; ++e)
    {
        enemy = &mEnemies[e];
        if (enemy->alive == 1 && CheckSameRoom(player.x, player.y, enemy->x, enemy->y) == 1)
            DrawEnemy(enemy);
    } */

    //cpc_PutSp(mCharacterDataBar, 40, 80, 0xC640);  

    cpc_PutSp(mCharacterDataBar0, 6, 80, 0xC640);
    cpc_PutSp(mCharacterDataBar1, 29, 2, 0xF68E);
    cpc_PutSp(mCharacterDataBar2, 5, 80, 0xDF80);
    cpc_PutSp(mCharacterDataBar3, 29, 3, 0xF640);

    PauseMusic();
    PlayEffect(LOAD_MAP_FX); 
    PlaySong(SOUND_TABLE_MAINEXPL, RULE_TABLE_MAINEXPL, EFFECT_TABLE, SONG_TABLE_MAINEXPL);       
}

main()
{
    unsigned char e = 0;
    unsigned char engaged = 0;
    TEnemy *enemy;
    TObject *potion;

    mLevel = 1;
    waitingTurns = 0;

    SetInks(mPalette);
    cpc_SetBorder(0);
    cpc_SetModo(0);

    cpc_SetInkGphStr(0, 42);
    cpc_SetInkGphStr(1, 160);
    cpc_SetInkGphStr(2, 160);
    cpc_SetInkGphStr(3, 160);

    cpc_DisableFirmware();

    xNextMap = 1;
    yNextMap = 1;
    estadoNextMap = 0;
    TILES_TO_PROCESS = 60;
    ShowMenu();
    GreyBackground();
    cpc_PrintGphStrXY("LOADING;CAVE", 28, 95);

    CreateTiles();

    InitializeLevel();
      
    // Main game loop.
    while(1) 
    {
        //WaitVSYNC();
        //Pause(42);
        GenerateNextMap();

        // While the player is alive we keep playing.
        if(player.alive)
        {
            engaged = 0;

            // Listen for a possible player action.
            if (waitingTurns == 0)
            {
                PlayerAction();

                if(player.potions < 3)
                    waitingTurns = 0;
                else
                    waitingTurns =1;
            }
            else
                --waitingTurns;

            // Process the enemies AI and execute their actions.
            for (e = 0; e < MAX_ENEMIES; ++e)
            {
                enemy = &mEnemies[e];

                if (enemy->type == TIRAMOCO)
                    UpdateMoco(enemy, &player);

                if (enemy->alive == 1)
                {
                    ExecuteStrategy(enemy, &player, mMap, MAP_WIDTH, mTiles,mEnemies,MAX_ENEMIES);
                    //if (enemy->redraw == 1 && CheckSameRoom(player.x, player.y, enemy->x, enemy->y) == 1)
                        //MarkTile(enemy->x, enemy->y);
                    ExecuteAction(enemy, &player, mPaletteHitHW, mPaletteHW);

                    // Alert the player with border color if an enemy is engaging him.
                    if (enemy->currentStrategy == ST_ENGAGE)
                        ++engaged;
                }
            }

            // Alert the player with border color if an enemy is engaging him.
            if (engaged)
                cpc_SetColour(17, 28);
            else
                cpc_SetColour(17, 20);

            // Redraw the map marked tiles.
            DrawMarkedTiles(player.x, player.y, 0xC000);

            // Draw the ladder if it is in the same room as the player.
            if(CheckSameRoom(player.x, player.y, mLadder.x, mLadder.y) == 1)
                cpc_PutMaskSp(mLadder.sprite, 8, 4, 0xC000 + 0x0050*(mLadder.y%20) + (mLadder.x%20)*0x0004);

            
            if(CheckSameRoom(player.x, player.y, mArmor.x, mArmor.y) == 1 && mArmor.picked == 0)
                cpc_PutSp(mArmor.sprite, 8, 4, 0xC000 + 0x0050*(mArmor.y%20) + (mArmor.x%20)*0x0004);

            // Draw the potions which are in the same room as the player and not yet picked.
            for (e = 0; e < MAX_POTIONS; ++e)
            {
                potion = &mPotions[e];
                if (potion->picked == 0 && CheckSameRoom(player.x, player.y, potion->x, potion->y) == 1)
                    DrawPotion(potion);
            }

            // Draw the enemies which are in the same room and alive.
            for (e = 0; e < MAX_ENEMIES; ++e)
            {
                enemy = &mEnemies[e];
                if (enemy->redraw == 1 && CheckSameRoom(player.x, player.y, enemy->x, enemy->y) == 1)
                {
                    DrawEnemy(enemy);

                    if (enemy->alive == 1)
                        enemy->redraw = 0;
                }

                if (enemy->type == TIRAMOCO && (enemy->moco.speedX != 0 || enemy->moco.speedY != 0) &&
                    CheckSameRoom(player.x, player.y, enemy->moco.x, enemy->moco.y) == 1)
                    DrawMoco(enemy);
            }     

            // Draw the player on screen (after ladder to overlap).
            DrawPlayer(&player);
            DrawStatusBar();

            // If we reach the ladder, go to the next level.
            if (player.potions == MAX_POTIONS && player.x == mLadder.x && player.y == mLadder.y)
            {
                cpc_SetColour(17, 20);
                ++mLevel;
                PauseMusic();
                PlayEffect(PICK_LAD_FX);
                ShowLoading();
                InitializeLevel();
                UpdateEnemies();
            }
        }
        // Game over, wait a bit and restart the level.
        else
        {
            cpc_SetColour(17, 20);
            DrawStatusBar();
            mLevel = 1;
            PauseMusic();
            PlayEffect(ROG_DEATH_FX);
            
            Pause(500);
            ShowDeath();
            // RESTART GAME TODO
            InitializeLevel();
        }
    }
}


