/// @file 		music.h
/// @author		CloseToMetal
/// @version	1.0
/// @date		13/10/2014
///
///	@section	License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

#ifndef MUSIC_H_
#define MUSIC_H_

/// @brief		Music player.
/// @details	Checks if a previous song is playing and reproduces the chosen music.
/// @param		soundTable Sounds table.
/// @param		ruleTable Instruments patterns.
/// @param		effectTable Effects table.
/// @param		songTable Song table where the musical notes are stored.
void PlaySong(int* soundTable, int* ruleTable, int* effectTable, int* songTable);

/// @brief		Music pauser.
/// @details	If a song is currently in reproduction it is paused.
void PauseMusic();

/// @brief		Continue music.
/// @details	If a song was paused, this reproduces it again.
//void ContinueMusic();

/// @brief		Effect player.
/// @details	Reproduces the selected effect.
/// @param		effect Effect position in the EffectTable.
void PlayEffect(int effect);

#endif