/// @file 		music_data.h
/// @author		Brayan Stiven Zapata Impatá <brayan.inf@gmail.com>
/// @version	3.0
/// @date		21/10/2014
///
///	@section	License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

/// @brief 		Effects array, every position stores a whole effect data.
extern const int EFFECT_TABLE[];

/// @brief 		Song, rule and sound tables por main exploration theme.
extern const int SONG_TABLE_MAINEXPL[];
extern const int RULE_TABLE_MAINEXPL[];
extern const int SOUND_TABLE_MAINEXPL[];

/// @brief 		Song, rule and sound tables por menu theme.
extern const int SONG_TABLE_MENU[];
//extern const int RULE_TABLE_MENU[];
//extern const int SOUND_TABLE_MENU[];

/// @brief 		Song, rule and sound tables por loading map theme.
extern const int SONG_TABLE_LOADMAP[];
//extern const int RULE_TABLE_LOADMAP[];
//extern const int SOUND_TABLE_LOADMAP[];

/// @brief		Effects const values declared in order to ease their use.
extern const int MENU_MOV_FX=0;
extern const int COLLISION_FX=1;
extern const int ATTACK_FX=2;
extern const int LOAD_MAP_FX=3;
extern const int ENE_DEATH_FX=4;
extern const int ROG_DEATH_FX=5;
extern const int PICK_LAD_FX=6;
/*extern const int SEEN_FX=7;
extern const int HEARD_FX=8;
extern const int CRIT_FX=9;
*/

/// @brief		Music data loader.
/// @details 	Every song and effect data is load here.
void the_music_data() {  
__asm

	///////////////////////////////////////////////////////
	/// MAIN EXPLORATION THEME ////////////////////////////
	///////////////////////////////////////////////////////

	/// SONG TABLE (.mus file)
	/// The song's frecuencies and data should be load here.
	_SONG_TABLE_MAINEXPL:
	    .DW _SONG_MAINEXPL

	///RULE TABLE (.mus.asm file)
	///Patterns are load here. (Instruments information).
	_RULE_TABLE_MAINEXPL:
	    .DW P0
		P0: .DB #9,#0,#9,#0,#9,#0,#9,#0,#129
		
	///SOUNDS TABLE (.mus.asm file)
	_SOUND_TABLE_MAINEXPL:
		.DW #0
		/*.DW SONIDO0, SONIDO1

		SONIDO0:	.DB	#189,#12,#0,#255
		SONIDO1:	.DB	#5,#60,#0,#255*/

	///////////////////////////////////////////////////////
	/// MENU THEME ////////////////////////////////////////
	///////////////////////////////////////////////////////
	_SONG_TABLE_MENU:
	    .DW _SONG_MENU

	/*_RULE_TABLE_MENU:
	    .DW P1
		P1: .DB #9,#0,#9,#0,#9,#0,#9,#0,#129
		
	_SOUND_TABLE_MENU:
		.DW #0*/

	///////////////////////////////////////////////////////
	/// LOADMAP THEME /////////////////////////////////////
	///////////////////////////////////////////////////////
	_SONG_TABLE_LOADMAP:
	    .DW _SONG_LOADMAP

	/*_RULE_TABLE_LOADMAP:
	    .DW P2
		P2: .DB #10,#0,#10,#0,#10,#0,#10,#0,#129
		
	_SOUND_TABLE_LOADMAP:
		.DW #0*/

	///////////////////////////////////////////////////////
	/// FXs THEME /////////////////////////////////////////
	///////////////////////////////////////////////////////
	_EFFECT_TABLE:
		.DW _EFECT0, _EFECT1, _EFECT2, _EFECT3, _EFECT4, _EFECT5
		.DW _EFECT6, _EFECT7, _EFECT8, _EFECT9, _EFECT10

		_EFECT0: ///Menu mov.
			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D

			.DB #0x06, #0x0D
			.DB #0x06, #0x0D
			.DB #0x06, #0x0D

			.DB #0xFF

		_EFECT1: ///Collision
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D

			.DB #0xFF

		_EFECT2: ///Attack Roguelio
			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0C
			.DB #0x9E, #0x0B

			.DB #0xFF

		_EFECT3: ///Load map
			.DB #0x17, #0x0D
			.DB #0x17, #0x0D
			.DB #0x17, #0x0D
			.DB #0x17, #0x0D
			.DB #0x17, #0x0D
			.DB #0x17, #0x0D

			.DB #0x16, #0x0D
			.DB #0x16, #0x0D
			.DB #0x16, #0x0D
			.DB #0x16, #0x0D
			.DB #0x16, #0x0D
			.DB #0x16, #0x0D

			.DB #0xFF

		_EFECT4: ///Enemy death
			.DB #0x8F, #0xDF
			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF

			.DB #0x00, #0x00
//			.DB #0x00, #0x00

			.DB #0x8F, #0xDF
			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF

			.DB #0x00, #0x00
//			.DB #0x00, #0x00

			.DB #0x8F, #0xDF
			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF

			.DB #0x00, #0x00
//			.DB #0x00, #0x00

			.DB #0x8F, #0xDF
			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF
//			.DB #0x8F, #0xDF

			.DB #0xFF

		_EFECT5: ///ROGUELIO faith
			.DB #0x12, #0x0F
			.DB #0x12, #0x0F
//			.DB #0x12, #0x0F
//			.DB #0x12, #0x0F

			.DB #0xFD, #0x0F
			.DB #0xFD, #0x0F
//			.DB #0xFD, #0x0F
//			.DB #0xFD, #0x0F

			.DB #0x32, #0x0F
			.DB #0x32, #0x0F
//			.DB #0x32, #0x0F
//			.DB #0x32, #0x0F

			.DB #0xD3, #0x0F
			.DB #0xD3, #0x0F
//			.DB #0xD3, #0x0F
//			.DB #0xD3, #0x0F

			.DB #0x8A, #0x0F
			.DB #0x8A, #0x0F
//			.DB #0x8A, #0x0F
//			.DB #0x8A, #0x0F
			
			.DB #0xEB, #0x0F
			.DB #0xEB, #0x0F
//			.DB #0xEB, #0x0F
//			.DB #0xEB, #0x0F
			
			.DB #0xAA, #0x0F
			.DB #0xAA, #0x0F
//			.DB #0xAA, #0x0F
//			.DB #0xAA, #0x0F
			
			.DB #0x27, #0x0F
			.DB #0x27, #0x0F
//			.DB #0x27, #0x0F
//			.DB #0x27, #0x0F

			.DB #0xFF

		_EFECT6: //Pick ladder
			.DB #0xFD, #0x0D
			.DB #0xFD, #0x0D
//			.DB #0xFD, #0x0D
//			.DB #0xFD, #0x0D

			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D
//			.DB #0x9E, #0x0D
//			.DB #0x9E, #0x0D
			.DB #0x19, #0x0D
			.DB #0x19, #0x0D
//			.DB #0x19, #0x0D
//			.DB #0x19, #0x0D

			.DB #0x00, #0x00
			.DB #0x00, #0x00
//			.DB #0x00, #0x00
//			.DB #0x00, #0x00

			.DB #0x9E, #0x0D
			.DB #0x9E, #0x0D
//			.DB #0x9E, #0x0D
//			.DB #0x9E, #0x0D
			.DB #0x19, #0x0D
			.DB #0x19, #0x0D
//			.DB #0x19, #0x0D
//			.DB #0x19, #0x0D

			.DB #0xFF

		_EFECT7: //Seen	
			.DB #0xA6, #0x0F
			.DB #0xA6, #0x0F
			.DB #0xA6, #0x0F

			.DB #0x00, #0x00
			.DB #0x00, #0x00

			.DB #0x19, #0x0F
			.DB #0x19, #0x0F
			.DB #0x19, #0x0F

			.DB #0x00, #0x00
			.DB #0x00, #0x00

			.DB #0xD6, #0x0F
			.DB #0xD6, #0x0F
			.DB #0xD6, #0x0F

			.DB #0x00, #0x00
			.DB #0x00, #0x00

			.DB #0x85, #0x0F
			.DB #0x85, #0x0F
			.DB #0x85, #0x0F	
		
			.DB #0xFF

		_EFECT8: //Heard
			/*.DB #0x0C, #0x0F
	
			.DB #0xCC, #0x0F
			
			.DB #0x6C, #0x0F
			
			.DB #0x9C, #0x0F
			.DB #0x9C, #0x0F
			.DB #0x9C, #0x0F

			.DB #0x0C, #0x0A
	
			.DB #0xCC, #0x0A
			
			.DB #0x6C, #0x0A
			
			.DB #0x9C, #0x0A
			.DB #0x9C, #0x0A
			.DB #0x9C, #0x0A*/

			.DB #0xEB, #0x0A
			.DB #0xEB, #0x0B
			.DB #0xEB, #0x0C
			.DB #0xEB, #0x0D
			.DB #0xEB, #0x0E
			.DB #0xEB, #0x0E
			.DB #0xEB, #0x0F
			.DB #0xEB, #0x0F
			.DB #0xEB, #0x0F
			.DB #0xEB, #0x0E
			.DB #0xEB, #0x0E
			.DB #0xEB, #0x0D
			.DB #0xEB, #0x0C
			.DB #0xEB, #0x0B
			.DB #0xEB, #0x0A

			.DB #0xFF

		_EFECT9: //Crit
			.DB #0xEB, #0x0F
			.DB #0xEB, #0x0F
			.DB #0xEB, #0x0F

			.DB #0x9E, #0x0F
			.DB #0x9E, #0x0F
			.DB #0x9E, #0x0E
			.DB #0x9E, #0x0F
			.DB #0x9E, #0x0F
			.DB #0x9E, #0x0F

			.DB #0xFF

		_EFECT10: ///Attack Enemy
			.DB #0xD3, #0x0D
			.DB #0xD3, #0x0D
			.DB #0xD3, #0x0D
			.DB #0xD3, #0x0D
			.DB #0xD3, #0x0C
			.DB #0xD3, #0x0B

			.DB #0xFF

__endasm;
}

/// @brief 		Main exploration theme data extracted from .mus file.
const unsigned char SONG_MAINEXPL[] = {
	/*// Aguda
	0x0c, 0x07, 0x00, 0x00, 0x3f, 0x00, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x21, 0x28, 0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x21, 0x28,
	0x2d, 0x28, 0x21, 0x2d, 0x21, 0x28, 0x23, 0x2a, 0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x23, 0x2a,
	0x2f, 0x2a, 0x23, 0x2f, 0x23, 0x2a, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe,
	0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xc1, 0xfe,
	0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xb9, 0x01, 0x01, 0x39, 0x36, 0xb4, 0x01, 0x01, 0x34, 0x36, 0xbb,
	0x01, 0x01, 0x3b, 0x39, 0xbb, 0x01, 0x01, 0x3b, 0x3b, 0xb9, 0x01, 0x01, 0x39, 0x36, 0xb4, 0x01,
	0x01, 0x34, 0x36, 0xbb, 0x01, 0x01, 0x3b, 0x39, 0xbb, 0x01, 0x01, 0x3b, 0x3b, 0xb9, 0x01, 0x01,
	0x39, 0x36, 0xb4, 0x01, 0x01, 0x34, 0x36, 0xbb, 0x01, 0x01, 0x3b, 0x39, 0xbb, 0x01, 0x01, 0x3b,
	0x3b, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe,
	0xfe, 0xfe, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xa1, 0x41, 0x21, 0x01, 0xa1, 0x41, 0x61,
	0xa3, 0x41, 0x23, 0x01, 0xa3, 0x41, 0x63, 0xa1, 0x41, 0x21, 0x01, 0xa1, 0x41, 0x61, 0xa3, 0x41,
	0x23, 0x01, 0xa3, 0x41, 0x63, 0xa1, 0x41, 0x21, 0x01, 0xa1, 0x41, 0x61, 0xa3, 0x41, 0x23, 0x01,
	0xa3, 0x41, 0x63, 0xa1, 0x41, 0x21, 0x01, 0xa1, 0x41, 0x61, 0xa3, 0x41, 0x23, 0x01, 0xa3, 0x41,
	0x63, 0xa1, 0x41, 0x21, 0x01, 0xa1, 0x41, 0x61, 0xa3, 0x41, 0x23, 0x01, 0xa3, 0x41, 0x63, 0xa1,
	0x41, 0x21, 0x01, 0xa1, 0x41, 0x61, 0xa3, 0x41, 0x23, 0x01, 0xa3, 0x41, 0x63, 0x00, 0xc1, 0x00,
	0x00*/
	// Grave (preferible)
	0x0c, 0x07, 0x00, 0x00, 0x3f, 0x00, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe,
	0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xc1, 0xfe,
	0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xad, 0x01, 0x01, 0x2d, 0x2a, 0xa8, 0x01, 0x01, 0x28, 0x2a, 0xaf,
	0x01, 0x01, 0x2f, 0x2d, 0xaf, 0x01, 0x01, 0x2f, 0x2f, 0xad, 0x01, 0x01, 0x2d, 0x2a, 0xa8, 0x01,
	0x01, 0x28, 0x2a, 0xaf, 0x01, 0x01, 0x2f, 0x2d, 0xaf, 0x01, 0x01, 0x2f, 0x2f, 0xad, 0x01, 0x01,
	0x2d, 0x2a, 0xa8, 0x01, 0x01, 0x28, 0x2a, 0xaf, 0x01, 0x01, 0x2f, 0x2d, 0xaf, 0x01, 0x01, 0x2f,
	0x2f, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe,
	0xfe, 0xfe, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55,
	0x97, 0x41, 0x17, 0x01, 0x97, 0x41, 0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41,
	0x17, 0x01, 0x97, 0x41, 0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01,
	0x97, 0x41, 0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01, 0x97, 0x41,
	0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01, 0x97, 0x41, 0x57, 0x95,
	0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01, 0x97, 0x41, 0x57, 0x00, 0xc1, 0x00,
 	0x00
	/*// Marchosa
	0x0c, 0x07, 0x00, 0x00, 0x3f, 0x00, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x15, 0x1c, 0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x15, 0x1c,
	0x21, 0x1c, 0x15, 0x21, 0x15, 0x1c, 0x17, 0x1e, 0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x17, 0x1e,
	0x23, 0x1e, 0x17, 0x23, 0x17, 0x1e, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe,
	0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xc1, 0xfe,
	0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xad, 0x01, 0x01, 0x2d, 0x2a, 0xa8, 0x01, 0x01, 0x28, 0x2a, 0xaf,
	0x01, 0x01, 0x2f, 0x2d, 0xaf, 0x01, 0x01, 0x2f, 0x2f, 0xad, 0x01, 0x01, 0x2d, 0x2a, 0xa8, 0x01,
	0x01, 0x28, 0x2a, 0xaf, 0x01, 0x01, 0x2f, 0x2d, 0xaf, 0x01, 0x01, 0x2f, 0x2f, 0xad, 0x01, 0x01,
	0x2d, 0x2a, 0xa8, 0x01, 0x01, 0x28, 0x2a, 0xaf, 0x01, 0x01, 0x2f, 0x2d, 0xaf, 0x01, 0x01, 0x2f,
	0x2f, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe,
	0xfe, 0xfe, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55,
	0x97, 0x41, 0x17, 0x01, 0x97, 0x41, 0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41,
	0x17, 0x01, 0x97, 0x41, 0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01,
	0x97, 0x41, 0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01, 0x97, 0x41,
	0x57, 0x95, 0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01, 0x97, 0x41, 0x57, 0x95,
	0x41, 0x15, 0x01, 0x95, 0x41, 0x55, 0x97, 0x41, 0x17, 0x01, 0x97, 0x41, 0x57, 0x00, 0x7f, 0x41,
	0x7f, 0x40, 0x7e, 0x7f, 0x01, 0x7f, 0x41, 0x7f, 0x41, 0x7f, 0x40, 0x7e, 0x7f, 0x01, 0x7f, 0x41,
	0x7f, 0x41, 0x7f, 0x40, 0x7e, 0x7f, 0x01, 0x7f, 0x41, 0x7f, 0x41, 0x7f, 0x40, 0x7e, 0x7f, 0x01,
	0x7f, 0x41, 0x7f, 0x41, 0x7f, 0x40, 0x7e, 0x7f, 0x01, 0x7f, 0x41, 0x7f, 0x41, 0x7f, 0x40, 0x7e,
	0x7f, 0x01, 0x7f, 0x41, 0x7f, 0x41, 0x7f, 0x40, 0x7e, 0x7f, 0x01, 0x7f, 0x41, 0x7f, 0x41, 0x7f,
	0x40, 0x7e, 0x7f, 0x01, 0x7f, 0x41, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x00, 0x7f, 0x01, 0x7f, 0x01,
	0x7f, 0x01, 0x7f, 0x01, 0x7f, 0x01, 0x00, 0x00 */
};


/// @brief 		Menu theme data extracted from .mus file.
const unsigned char SONG_MENU[] = {
	0x08, 0x07, 0x00, 0x00, 0x3f, 0x00, 0x92, 0x01, 0x12, 0x12, 0x12, 0x01, 0x12, 0x01, 0x12, 0x92,
	0x01, 0x12, 0x12, 0x12, 0x01, 0x12, 0x01, 0x12, 0x95, 0x01, 0x15, 0x15, 0x15, 0x01, 0x17, 0x01,
	0x15, 0x01, 0x93, 0x01, 0x13, 0x13, 0x13, 0x01, 0x15, 0x01, 0x13, 0x01, 0x92, 0x01, 0x12, 0x12,
	0x12, 0x01, 0x12, 0x01, 0x12, 0x92, 0x01, 0x12, 0x12, 0x12, 0x01, 0x12, 0x01, 0x12, 0x95, 0x01,
	0x15, 0x15, 0x15, 0x01, 0x17, 0x01, 0x15, 0x01, 0x93, 0x01, 0x13, 0x13, 0x13, 0x01, 0x15, 0x01,
	0x13, 0x01, 0x00, 0x3f, 0x00, 0x99, 0xc1, 0x99, 0xc1, 0x9c, 0xc1, 0x01, 0x9a, 0xc1, 0x01, 0xaa,
	0x01, 0x25, 0x25, 0x25, 0x01, 0x25, 0x01, 0x25, 0xa5, 0x01, 0x25, 0x25, 0x25, 0x01, 0x25, 0x01,
	0x25, 0xa8, 0x01, 0x28, 0x28, 0x28, 0x01, 0x2a, 0x01, 0x28, 0x01, 0xa6, 0x01, 0x26, 0x26, 0x26,
	0x01, 0x28, 0x01, 0x26, 0x01, 0x00, 0x3f, 0x00, 0xc1, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe,
	0xfe, 0xfe, 0xfe, 0x41, 0x9e, 0xc1, 0xaa, 0xc1, 0xa1, 0xc1, 0x01, 0x9f, 0xc1, 0x01, 0x00, 0xc1,
	0x00, 0x00 
};

/// @brief 		Loading map theme data extracted from .mus file.
const unsigned char SONG_LOADMAP[] = {
	0x16, 0x07, 0x00, 0x00, 0x3f, 0x00, 0x52, 0x59, 0x55, 0x7e, 0x01, 0x52, 0x59, 0x55, 0x7e, 0x01,
	0xc1, 0x17, 0x17, 0x5e, 0x1a, 0x21, 0x1f, 0x1e, 0x00, 0xc1, 0x00, 0x3f, 0x00, 0xc1, 0xc1, 0x57,
	0x5e, 0x5a, 0x7e, 0x01, 0x81, 0x1a, 0x21, 0x1f, 0x1e, 0x00, 0xc1, 0x00, 0x00
};