/// @file 		pathfinding.c
/// @author		CloseToMetal
/// @version	1.0
/// @date		17/10/2014
///
///	@section	License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.
#include "pathfinding.h"


//// Auxiliar char matrix of size COLxROW used for computing the path	
char auxiliarMatrixPath[(COL*ROW)/8];

/// Array of chars used to store tilesPath coordinates tilesPath[0] = x1 ; tilesPath[1] = y1 ; tilesPath[2] = x2 ; tilesPath[3] = y2.
char tilesPath[CHAR_ARRAY_SIZE];

/// Global variable that stores the size of tilesPath array.
unsigned int arraySizePath;


char AddToList(char x, char y)
{
	char result = 0;

	if(arraySizePath < CHAR_ARRAY_SIZE)
	{
		tilesPath[arraySizePath] = x;
		arraySizePath++;
		tilesPath[arraySizePath] = y;
		arraySizePath++;
		result = 1;
	}

	return result;
}

char AdjacentTiles(char x, char y, char sX, char sY, char fX, char fY, char matrix[])
{
		///When result = 5 is because there is no valid adjacent tile. In that case we will proceed with backtracking.
		char result = 5; 
		
		///Distances between (x,y) and adjacent tilesPath: distance1 = (x,y) -> (x,y-1) - UP ; distance2 = (x,y) -> (x,y+1) - DOWN ; distance3 = (x,y) -> (x-1,y) - LEFT ; distance4 = (x+1,y) - RIGHT.
		char distance1 = 0; 
		char distance2 = 0;
		char distance3 = 0;
		char distance4 = 0;

		int down = (y+1)*COL + x;
		int up = (y-1)*COL + x;
		int right = y * COL + (x+1);
		int left = y * COL + (x-1);

		int auxDown = 0;
		int auxUp = 0;
		int auxRight = 0;
		int auxLeft = 0;

		/*Heurística*/
	    if(y == fY) //Alineado con el eje y. Limito movimiento en eje Y
    	{
    		if(sY < y)
    			setBit(auxiliarMatrixPath, (y-1) * COL + x, 1);
    		else
    			setBit(auxiliarMatrixPath, (y+1) * COL + x, 1);
    			
    		if(x < fX)
    			auxRight = -1;
    		if(x > fX)
    			auxLeft = -1;
    	}
    	
    	else if(x == fX)
    	{
    		if(sX < x)
    			setBit(auxiliarMatrixPath, y * COL + (x-1), 1);
    		else
    			setBit(auxiliarMatrixPath, y * COL + (x+1), 1);

    		if(y < fY)
    			auxDown = -1;
    		
    		if(y > fY)
    		    auxUp = -1;
    	}
        else
		{
    		if(sX < fX)
    		{
    			if(sY < fY)
    				auxDown = -1;
    			else
    				auxUp = -1;

    			auxRight = -1;
    		}
    		else if(sX > fX)
    		{
    			if(sY < fY)
    				auxDown = -1;
    			else
    				auxUp = -1;

    			auxLeft = -1;
    		}
		}
    	

		//Each IF sentence is for each adjacent movement (up, down, left and right). SWITCH sentences will compare the distances and return the shortest distance.
		///When there is no valid adjacent tile, we will proceed with backtracking until we reach an unexplored tile. 
		/// If the tile is not a wall getBit(matrix, up) != 1 and the tile is unexplored getBit(auxiliarMatrixPath, up) != 1
		if(getBit(matrix, up) != 1 && getBit(auxiliarMatrixPath, up) != 1)
		{
			distance1 = absolute(fX -  x) + absolute(fY - (y-1)) + auxUp; ///Manhattan distance
			result = 1; ///Upward movement
		}

		///Downward movement
		if(getBit(matrix, down) != 1 && getBit(auxiliarMatrixPath, down) != 1)
		{

			distance2 = absolute(fX -  x) + absolute(fY - (y + 1)) + auxDown; ///Manhattan distance

			switch(result) 
			{
				case 1: 
						if(distance1 > distance2)
							result = 2;
						break;

				default: result = 2; ///Downward movement
			}
		}	
			
		///Leftward movement
		if(getBit(matrix, left) != 1 && getBit(auxiliarMatrixPath, left) != 1) 
		{

			distance3 = absolute(fX - (x - 1)) + absolute(fY - y) + auxLeft; ///Manhattan distance

			switch(result)
			{
				case 1: 
						if(distance1 >= distance3)
							result = 3;
						break;

				case 2: if(distance2 >= distance3)
							result = 3;
						break;

				default : result = 3; ///Leftward movement
			}

		}

		/// Rightward movement
		if(getBit(matrix, right) != 1 && getBit(auxiliarMatrixPath, right) != 1) 
		{
			distance4 = absolute(fX - (x + 1)) + absolute(fY - y) + auxRight; ///Manhattan distance
		
			switch(result)
			{
				case 1: if(distance1 >= distance4)
							result = 4;
						break;

				case 2: if(distance2 >= distance4)
							result = 4;	
						break;

				case 3: if(distance3 > distance4)
							result = 4;
						break;

				default: result = 4; ///Rightward movement
			}
		}

		return result;
}


void PathFinding(char sX, char sY, char fX, char fY, TEnemy *pEnemy, char matrix[])
{
	char inserted;
	char auxiliar;
	char coordX = sX;
	char coordY = sY;
	int i = 0;
	int j = 0;
	int loop;
	char problem = 0;

	memset(auxiliarMatrixPath, 0, (COL*ROW)/8);

	arraySizePath = 0;
	loop = 1;
	setBit(auxiliarMatrixPath, (coordY * COL + coordX), 1);
	inserted = AddToList(coordX, coordY);

	while(loop)
	{
		if(coordX == fX && coordY == fY || inserted == 0 || arraySizePath == 0)
		{
			if(inserted == 0 || arraySizePath == 0)
			{
				pEnemy->pathNodes = 0;
				problem = 1;
			}
			
 			loop = 0;
		}
		else
		{
			auxiliar = AdjacentTiles(coordX, coordY, sX, sY, fX, fY, matrix);
		
			switch(auxiliar)
			{
				case 1:   setBit(auxiliarMatrixPath, (coordY-1) * COL + coordX, 1);

						  inserted = AddToList(coordX, coordY - 1);
						  coordY = coordY - 1;
						  i = i + 2;
						  break;

				case 2:   setBit(auxiliarMatrixPath, (coordY+1) * COL + coordX, 1);

						  inserted = AddToList(coordX, coordY + 1);
						  coordY = coordY + 1;
						  i = i + 2;
						  break;

				case 3:   setBit(auxiliarMatrixPath, coordY * COL + (coordX-1), 1);
						  inserted = AddToList(coordX - 1, coordY);
						  coordX = coordX - 1;
						  i = i + 2;
						  break;

				case 4:   setBit(auxiliarMatrixPath, coordY * COL + (coordX+1), 1);
						  inserted = AddToList(coordX + 1, coordY);
						  coordX = coordX + 1;
						  i = i + 2;
						  break;

				///Backtracking case
				case 5:   setBit(auxiliarMatrixPath, coordX * COL + coordX, 1);
						  arraySizePath = arraySizePath - 2;
						  i--;
						  coordY = tilesPath[i];
						  i--;
						  coordX = tilesPath[i];
						  break;
			}
		}
	}


	if(problem == 0)
	{
		if(arraySizePath < ENEMY_ARRAY_SIZE)
				pEnemy->pathNodes = arraySizePath;
		else
				pEnemy->pathNodes = ENEMY_ARRAY_SIZE;
		
		for(j = 0; j < ENEMY_ARRAY_SIZE; j++)
					pEnemy->path[j] = tilesPath[j];
	}
}