/// @file 		pathfinding.h
/// @author		CloseToMetal
/// @version	1.0
/// @date		17/10/2014
///
///	@section	License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.
#ifndef PATHFINDING_H_
#define PATHFINDING_H_

#include "utils.h"
#include "enemy.h"
#include "string.h"

/// @brief Pathfinding constants: ROW and COL define the measures of the auxiliar matrix.
///            					 NUM_OF_CELLS define the size of the array of chars used to store the path 
#define ROW 60
#define COL 60
#define CHAR_ARRAY_SIZE 400
#define ENEMY_ARRAY_SIZE 60

/// @brief AddToList function 
/// @details Function used to add a tile (x,y) of the path to the list.
///
/// @param x - X coordinate for a tile (columns)
/// @param y - Y coordinate for a tile (rows)
/// @return - 1 if the tile was inserted correctly, 0 otherwise.
char AddToList(char x, char y);

/// @brief AdjacentTiles function
/// @details Function responsible for examining the adjacent tiles for (x,y) tile. The function uses an heuristic to determine
/// the best adjacent tile in order to reach the destination (fX, fY).
///
/// @param x - X coordinate for the current tile.
/// @param y - Y coordinate for the current tile.
/// @param fX - Destination tile X coordinate.
/// @param fY - Destination tile Y coordinate.
char AdjacentTiles(char x, char y, char sX, char sY, char fX, char fY, char matrix[]);


/// @brief Pathfinding function
/// @details Main function that computes the path between two tiles (sX,sY) - (fX,fY).
///
/// @param sX - Starting tile X coordinate.
/// @param sY - Starting tile Y coordinate.
/// @param fX - Destination tile X coordinate.
/// @param fY - Destination tile Y coordinate.
void PathFinding(char sX, char sY, char fX, char fY, TEnemy *pEnemy, char matrix[]);

#endif