/// @file 		player.h
/// @author		CloseToMetal
/// @version	1.0
/// @date		14/10/2014
///
///	@section	License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.
#ifndef PLAYER_H_
#define PLAYER_H_

/// @brief 		Basic player data structure.
typedef struct player
{
	/// Coordinates of the position.
	unsigned char x;
	unsigned char y;
	/// Pointer to the spritesheet (right-bottom-left-top).
	char *sprite;
	/// Pointer to the dead player sprite.
	char *spriteDeath;
	/// Look direction of the player (0-right, 64-bottom, 128-left, 192-top) to offset the sprite.
	unsigned char direction;
	/// Flag of turn movement.
	unsigned char moved;
	/// Player game attributes.
	unsigned char armor;
	unsigned char strengthMax;
	unsigned char strengthMin;
	unsigned char health;
	unsigned char critProb;
	/// ¿Are we alive?
	unsigned char alive;
	unsigned char potions;
} TPlayer;

/// @brief		Player drawing routine.
/// @details	Draws the specified player on screen based on its position.
/// @param		pPlayer Pointer to the player structure to draw.
void DrawPlayer(TPlayer *pPlayer);
/// @brief 		Player attack damage calculator.
/// @details	Calculates the total amount of damage that the player will
/// 			deal with a single strike, taking into account his damage interval
///				(max-min strenght) and his critical strike probability.
/// @param		pPlayer Pointer to the struct of the player who strikes.
/// @return		The total amount of damage with all the modifiers.
unsigned char StrikeEnemy(TPlayer *pPlayer);
/// @brief		Armor damage reduction.
/// @details	Calculates the damage reduction factor which a certain armor
///				value provides in combat, following a semi logarithmic approach.
/// @param		pArmor The amount of armor.
/// @return		Damage reduction factor of the armor.
float DamageReduction(char pArmor);

#endif