/// @file       randomfloor.c
/// @author     CloseToMetal
/// @version    1.0
/// @date       06/10/2014
///
/// @section    License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

#include "randomfloor.h"
#include "cpcrslib.h"
#include <string.h>


void InitFloor(char *floor, unsigned int rows, unsigned int cols, unsigned int type, unsigned int x, unsigned int y, unsigned int nTiles)
{
	unsigned int stopi;
	unsigned int stopj;
	unsigned int i;
	unsigned int j;

	if (type == 0)
	{
		if(y == 1 && x == 1)
		{
			for(i = 0; i < rows; ++i)
			{
				setBit(floor, i*cols, 1);
				setBit(floor, (i+1)*cols-1, 1);
			}

			for(j = 0; j < cols; ++j)
			{
				setBit(floor, j, 1);
				setBit(floor, (rows-1)*cols+j, 1);
			}
		}

		if(nTiles == 0)
		{
			stopi = rows-1;
			stopj = cols-1;
		}
		else
		{
			stopi = y + 1;
			if(stopi > rows-1) stopi = rows-1;
			stopj = x + nTiles;
			if(stopj > cols-1) stopj = cols-1;
		}
	
	
		for(i = y; i < stopi; ++i)
		{
			for(j = x; j < stopj; ++j)
			{
				setBit(floor, i*cols+j, (cpc_Random() % 100) < 39);
			}
		}
	}
	else
	{
		//memset(floor, 1, (rows*cols)/8);
		for(i = 0; i < rows; ++i)
		{
			for(j = 0; j < cols; ++j)
			{
				setBit(floor, i*cols+j, 1);
			}
		}
	}
}


unsigned int WallsArround(char *floor, unsigned int pos, unsigned int cols)
{
	unsigned int wallCount;
	wallCount = 0;

	if(getBit(floor, pos-cols-1) == 1) wallCount++;
	if(getBit(floor, pos-cols  ) == 1) wallCount++;
	if(getBit(floor, pos-cols+1) == 1) wallCount++;

	if(getBit(floor, pos-1) == 1) wallCount++;
	if(getBit(floor, pos+1) == 1) wallCount++;

	if(getBit(floor, pos+cols-1) == 1) wallCount++;
	if(getBit(floor, pos+cols  ) == 1) wallCount++;
	if(getBit(floor, pos+cols+1) == 1) wallCount++;

	return wallCount;
}


unsigned int WallsArround2(char *floor, unsigned int i, unsigned int j, unsigned int rows, unsigned int cols)
{
	unsigned int wallCount;
	wallCount = 0;

	if(i != 1)
	{
		if(j != 1)
			if(getBit(floor, (i-2) * cols + (j-2)) == 1) wallCount++;
		if(getBit(floor, (i-2) * cols + (j-1)) == 1) wallCount++;
		if(getBit(floor, (i-2) * cols + j    ) == 1) wallCount++;
		if(getBit(floor, (i-2) * cols + (j+1)) == 1) wallCount++;
		if(j != cols-2)
			if(getBit(floor, (i-2) * cols + (j+2)) == 1) wallCount++;
	}

	if(j != 1)
	{
		if(getBit(floor, (i-1) * cols + (j-2)) == 1) wallCount++;
		if(getBit(floor,   i   * cols + (j-2)) == 1) wallCount++;
		if(getBit(floor, (i+1) * cols + (j-2)) == 1) wallCount++;
	}
	else if(j != cols-2)
	{
		if(getBit(floor, (i-1) * cols + (j+2)) == 1) wallCount++;
		if(getBit(floor,   i   * cols + (j+2)) == 1) wallCount++;
		if(getBit(floor, (i+1) * cols + (j+2)) == 1) wallCount++;
	}

	if(i != rows-2)
	{
		if(j != 1)
			if(getBit(floor, (i+2) * cols + (j-2)) == 1) wallCount++;
		if(getBit(floor, (i+2) * cols + (j-1)) == 1) wallCount++;
		if(getBit(floor, (i+2) * cols + j    ) == 1) wallCount++;
		if(getBit(floor, (i+2) * cols + (j+1)) == 1) wallCount++;
		if(j != cols-2)
			if(getBit(floor, (i+2) * cols + (j+2)) == 1) wallCount++;
	}

	return wallCount;
}


char GenerateCavePart(char *floor, unsigned int rows, unsigned int cols, char estado, unsigned int x, unsigned int y, unsigned int nTiles)
{
	unsigned int walls;
	unsigned int pos;
	unsigned int stopi;
	unsigned int stopj;
	unsigned int j;
	unsigned int i;
	i = 0;
	j = 0;
	pos = 1;
	if(estado >= 3) return 3;

	// Primer paso: Inicialización del mapa
	if(estado == 0)
	{
		InitFloor(floor, rows, cols, 0, x, y, nTiles);
		i = y;
		j = x + nTiles;
        if(j >= cols-1) ++i;

		if(nTiles == 0)
		{
			x = 1;
			y = 1;
			estado = 1;
		}
	}

	// Segundo paso: Primer algoritmo de refinado
	// Tercer paso: Segundo algoritmo de refinado, para suavizar el mapeado y eliminar
	//   muros que puedan quedar sueltos en zonas abiertas.
	if(estado == 1 || estado == 2)
	{
		do
		{
			if(nTiles == 0)
			{
				stopi = rows-1;
				stopj = cols-1;
			}
			else
			{
				stopi = y + 1;
				if(stopi > rows-1) stopi = rows-1;
				stopj = x + nTiles;
				if(stopj > cols-1) stopj = cols-1;
			}

			for(i = y; i < stopi; i++)
			{
				for(j = x; j < stopj; j++)
				{
					pos = i*cols+j;
					walls = WallsArround (floor, pos, cols);

					//Si un muro está rodeado de 4 o más muros, sigue siendo muro.
					if( getBit(floor, pos) == 1 && ((estado == 1 && walls >= 4) || (estado == 2 && walls >= 3)) )
					{
						//setBit(floor, pos, 1);
					}
					//Si un suelo está rodeado de 5 o más muros, pasa a ser muro.
					else if( getBit(floor, pos) == 0 && (walls >= 5))
					{
						setBit(floor, pos, 1);
					}
					//Si una casilla tiene uno o ningún muro a dos pasos, pasa a ser muro.
					else if(estado == 1 && (walls + WallsArround2(floor, i, j, rows, cols)) <= 1)
					{
						setBit(floor, pos, 1);
					}
					//En otro caso, la posición actual pasa a ser suelo.
					else
					{
						setBit(floor, pos, 0);
					}
				}
			}

			if(nTiles == 0)
			{
				x = 1;
				y = 1;
				if(estado == 1) pos = 0;
				else pos = 1;
				++estado;
			}
			else pos = 1;
		}
		while(pos == 0);
	}

	// Aquí se detecta si se ha terminado un paso, y se prepara el siguiente.
	if(i >= rows-1 && j >= cols-1) ++estado;

	return estado;
}


void IsConnected(char *floor, char *auxFloor, unsigned int pos, unsigned int cols)
{
	//Si en el mapa tenemos suelo.
	if(getBit(floor, pos) == 0)
	{
		//Y no lo hemos detectado aún como conexo en el auxiliar.
		if(getBit(auxFloor, pos) != 0)
		{
			//Lo ponemos como conexo si alguno a su alrededor lo es.
			if( (getBit(auxFloor, pos+1) == 0) ||
				(getBit(auxFloor, pos-1) == 0) ||
				(getBit(auxFloor, pos+cols) == 0) ||
				(getBit(auxFloor, pos-cols) == 0) )
			{
				setBit(auxFloor, pos, 0);						
			}
		}
	}
}


unsigned int EnsureConnectivity(char *floor, char *auxFloor, unsigned int rows, unsigned int cols)
{
	unsigned int i;
	unsigned int j;
	unsigned int x;
	unsigned int y;
	unsigned int pos;
	unsigned int nWalkable;
	char secondTry;
	nWalkable = 0;
	secondTry = 0;


	do
	{
		InitFloor(auxFloor, rows, cols, 1, 1, 1, 0);

		if(nWalkable == 0)
		{
			//Colocamos al personaje por el centro del mapa,
			//que suele contener la zona conexa principal.
			x = rows/2;
			y = cols/2;
		}
		else
		{
			x = 45;
			y = 45;
			secondTry = 1;
		}

		while(getBit(floor, (x*cols+y)) == 1)
	    {
	        if (y == cols)
	        {
	            y = 0;
	            ++x;
	        }
			++y;
	    }

	    //Marcamos la casilla escogida como conexa.
	    setBit(auxFloor, (x*cols+y), 0);

	    //Recorremos el mapa en múltiples direcciones marcando como conexas
	    //aquellas casillas que son suelo en el mapa principal y que tienen
	    //a su alrededor alguna casilla marcada como conexa.
		for(i = x; i < rows-1; ++i)
			for(j = y; j < cols-1; ++j)
				IsConnected(floor, auxFloor, i*cols+j, cols);

		for(i = rows-2; i > 0; --i)
			for(j = cols-2; j > 0; --j)
				IsConnected(floor, auxFloor, i*cols+j, cols);

		for(i = 1; i < x; ++i)
			for(j = 1; j < y; ++j)
				IsConnected(floor, auxFloor, i*cols+j, cols);

		for(j = 1; j < cols-1; ++j)
			for(i = 1; i < rows-1; ++i)
				IsConnected(floor, auxFloor, i*cols+j, cols);

		for(j = cols-2; j > 0; --j)
			for(i = rows-2; i > 0; --i)
				IsConnected(floor, auxFloor, i*cols+j, cols);

		for(j = cols-2; j > 0; --j)
			for(i = 1; i < rows-1; ++i)
				IsConnected(floor, auxFloor, i*cols+j, cols);

		for(j = 1; j < cols-1; ++j)
			for(i = rows-2; i > 0; --i)
				IsConnected(floor, auxFloor, i*cols+j, cols);


		//Por último aplicamos los cambios al mapa principal.
		nWalkable = 0;
		for(i = 1; i < rows-1; ++i)
		{
			for(j = 1; j < cols-1; ++j)
			{
				pos = i*cols+j;

				//Si en el mapa tenemos suelo y en el auxiliar lo tenemos como no conexo, lo convertimos en muro.
				if( (getBit(floor, pos) == 0) && (getBit(auxFloor, pos) == 1) )
				{
					setBit(floor, pos, 1);					
				}
				else if( (getBit(floor, pos) == 0) && (getBit(auxFloor, pos) == 0) )
				{
					++nWalkable;				
				}
			}
		}
	}
	while(nWalkable < 200 && secondTry == 0);

	return nWalkable;
}


unsigned int RandomPosition(char *floor, unsigned int rows, unsigned int cols)
{
	unsigned int i;
	unsigned int j;

	do
    {
	    i = (cpc_Random() % (rows-2)) + 1;
		j = (cpc_Random() % (cols-2)) + 1;
	}
	while(getBit(floor, (i * cols + j)) == 1);

    return (i * cols + j);
}


unsigned int RandomPositionBound(char *floor, unsigned int rows, unsigned int cols, unsigned int x, unsigned int y, unsigned int lowerBound, unsigned int upperBound)
{
	unsigned int xOffset;
	unsigned int yOffset;
	unsigned int range;
	unsigned int doubleRange;
	unsigned int i;
	unsigned int j;
	unsigned int count;

	range = upperBound - lowerBound;
	doubleRange = 2*range;
	count = 0;

	do
	{
		if(count == 50) return RandomPosition(floor, rows, cols);
		++count;
		xOffset = cpc_Random() % doubleRange;
		yOffset = cpc_Random() % doubleRange;

		if(xOffset < range)	j = x - lowerBound - xOffset;
		else				j = x + lowerBound + (xOffset - range);

		if(yOffset < range)	i = y - lowerBound - yOffset;
		else				i = y + lowerBound + (yOffset - range);
	}
	while(i >= rows || j >= cols || i < 1 || j < 1 || (getBit(floor, (i * cols + j)) == 1));

    return (i * cols + j);
}