/// @file 		tiles.h
/// @author		CloseToMetal
/// @version	1.0
/// @date		27/09/2014
///
///	@section	License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

#ifndef TILES_H_
#define TILES_H_

/// Maximum number of different tiles allowed.
#define MAX_TILES 4

/// @brief 	Minimum tile structure.
typedef struct tile {
	// Pointer to the sprite location (4x8 bytes).
	unsigned char *sprite;
	// Walkable flag for collision checking (1 if walkable, 0 otherwise).
	unsigned char walkable;
} TTile;

/// @brief		Walkable tile checker.
/// @details	Checks if the specified tile on a certain tile map with a tile set
///				is walkable or not.
/// @param		pTileMap The tile map to obtain the tiles.
/// @param		pTiles The tile set to obtain walkable flags.
/// @param		pMapWidth Width (in tiles) of the tile map.
/// @param		pX Position in the x-axis of the tile.
/// @param		pY Position in the y-axis of the tile.
/// @return		The walkable flag of the specified tile.
char CheckWalkableTile (unsigned char *pTileMap, TTile *pTiles, unsigned char pMapWidth, unsigned char pX, unsigned char pY);

#endif