/// @file       utils.c
/// @author     CloseToMetal
/// @version    2.0
/// @date       11/10/2014
///
/// @section    License
///
/// The MIT License (MIT)
/// 
/// Copyright (c) 2014 CloseToMetal
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

#include "utils.h"
#include "cpcrslib.h"

const unsigned int bitWeights[8] = {1,2,4,8,16,32,64,128};

void PrintNumber(unsigned char number, unsigned char x, unsigned char y)
{
	char cad[4];
 	cad[0] = (number / 100) + 48;
    cad[1] = (number - ((number / 100)*100)) / 10 + 48;
    cad[2] = (number - ((number - ((number / 100)*100))/10)*10) + 48;
    cad[3] = 0;
    cpc_PrintGphStrXY(cad, x, y);

}

void Pause(unsigned char p)
{
    unsigned char i;
    for (i = 0; i < p; ++i) 
    {
        __asm
            halt
        __endasm;
    }
}

char getBit(char *array, unsigned int pos)
{
	unsigned int byteV;
	unsigned int bitV;

	byteV = array[pos/8];
	bitV = bitWeights[pos%8];
	return (byteV & bitV) == bitV;
}

void setBit(char *array, unsigned int pos, unsigned int value)
{
	unsigned int byteV;
	unsigned int bytePos;
	unsigned int bitV;

	bytePos = pos/8;
	byteV = array[bytePos];
	bitV = bitWeights[pos%8];

	if(value == 0)
	{
		if(getBit(array, pos) != 0) array[bytePos] -= bitV;
	}
	else
	{
		if(getBit(array, pos) == 0) array[bytePos] += bitV;
	}

}

char absolute (char a)
{
	return (a < 0) ? -a : a;
}